==================================
 ``django_celery_monitor.camera``
==================================

.. contents::
    :local:
.. currentmodule:: django_celery_monitor.camera

.. automodule:: django_celery_monitor.camera
    :members:
